@@ -180,10 +180,7 @@ void object_set_key(QPDFObjectHandle h, std::string const& key, QPDFObjectHandle
     if (! str_startswith(key, "/"))
         throw py::key_error("PDF Dictionary keys must begin with '/'");
     if (h.isStream() && key == "/Length") {
-        PyErr_WarnEx(PyExc_DeprecationWarning,
-            "Modifications to /Length have no effect and will be forbidden in a future release.",
-            0
-        );
+        throw py::key_error("/Length may not be modified");
     }
 
     // For streams, the actual dictionary is attached to stream object
@@ -198,10 +195,7 @@ void object_del_key(QPDFObjectHandle h, std::string const& key)
     if (!h.isDictionary() && !h.isStream())
         throw py::value_error("object is not a dictionary or a stream");
     if (h.isStream() && key == "/Length") {
-        PyErr_WarnEx(PyExc_DeprecationWarning,
-            "Deleting /Length has no effect and will be forbidden in a future release.",
-            0
-        );
+        throw py::key_error("/Length may not be deleted");
     }
 
     // For streams, the actual dictionary is attached to stream object
@@ -220,7 +214,7 @@ std::pair<int, int> object_get_objgen(QPDFObjectHandle h)
 }
 
 
-void init_object(py::module& m)
+void init_object(py::module_& m)
 {
     py::enum_<QPDFObject::object_type_e>(m, "ObjectType")
         .value("uninitialized", QPDFObject::object_type_e::ot_uninitialized)
@@ -273,7 +267,7 @@ void init_object(py::module& m)
         .def("__repr__", &objecthandle_repr)
         .def("__hash__",
             [](QPDFObjectHandle &self) -> py::int_ {
-                py::object hash = py::module::import("builtins").attr("hash");
+                py::object hash = py::module_::import("builtins").attr("hash");
 
                 //Objects which compare equal must have the same hash value
                 switch (self.getTypeCode()) {
@@ -320,7 +314,7 @@ void init_object(py::module& m)
                 try {
                     q_other = objecthandle_encode(other);
                 } catch (const py::cast_error&) {
-                    return py::globals()["__builtins__"]["NotImplemented"];
+                    return py::reinterpret_borrow<py::object>(py::handle(Py_NotImplemented));
                 }
                 bool result = (self == objecthandle_encode(other));
                 return py::bool_(result);
@@ -730,7 +724,7 @@ void init_object(py::module& m)
                 OperandGrouper og(whitelist);
                 QPDFObjectHandle::parseContentStream(h, &og);
                 if (!og.getWarning().empty()) {
-                    auto warn = py::module::import("warnings").attr("warn");
+                    auto warn = py::module_::import("warnings").attr("warn");
                     warn(og.getWarning());
                 }
                 return og.getInstructions();
@@ -840,32 +834,7 @@ void init_object(py::module& m)
         "Construct a PDF Stream object from binary data",
         py::keep_alive<0, 1>() // returned object references the owner
     );
-    m.def("_new_stream",
-        [](std::shared_ptr<QPDF> owner, py::iterable content_stream) {
-            std::stringstream data;
-
-            for (auto handle_command : content_stream) {
-                py::tuple command = py::reinterpret_borrow<py::tuple>(handle_command);
-
-                if (command.size() != 2)
-                    throw py::value_error("Each item in stream data must be a tuple(operands, operator)");
-
-                py::object operands = command[0];
-                py::object operator_ = command[1];
-                for (auto operand : operands) {
-                    QPDFObjectHandle h = objecthandle_encode(operand);
-                    data << h.unparse();
-                    data << " ";
-                }
-                data << objecthandle_encode(operator_).unparse();
-                data << "\n";
-            }
-            return QPDFObjectHandle::newStream(owner.get(), data.str());
-        },
-        "Construct a PDF Stream object from a list of operand-operator tuples [((operands,), operator)]",
-        py::keep_alive<0, 1>() // returned object references the owner
-    );
-    m.def("Operator",
+    m.def("_new_operator",
         [](const std::string& op) {
             return QPDFObjectHandle::newOperator(op);
         },
